<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.aedev v0.3.32 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.namespace_root_tpls v0.3.27 -->
# project_tpls 0.3.77

[![GitLab develop](https://img.shields.io/gitlab/pipeline/aedev-group/aedev_project_tpls/develop?logo=python)](
    https://gitlab.com/aedev-group/aedev_project_tpls)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/aedev-group/aedev_project_tpls/release0.3.77?logo=python)](
    https://gitlab.com/aedev-group/aedev_project_tpls/-/tree/release0.3.77)
[![PyPIVersions](https://img.shields.io/pypi/v/aedev_project_tpls)](
    https://pypi.org/project/aedev-project-tpls/#history)

>aedev namespace package portion project_tpls: managed Python project files templates.

[![Coverage](https://aedev-group.gitlab.io/aedev_project_tpls/coverage.svg)](
    https://aedev-group.gitlab.io/aedev_project_tpls/coverage/index.html)
[![MyPyPrecision](https://aedev-group.gitlab.io/aedev_project_tpls/mypy.svg)](
    https://aedev-group.gitlab.io/aedev_project_tpls/lineprecision.txt)
[![PyLintScore](https://aedev-group.gitlab.io/aedev_project_tpls/pylint.svg)](
    https://aedev-group.gitlab.io/aedev_project_tpls/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/aedev_project_tpls)](
    https://gitlab.com/aedev-group/aedev_project_tpls/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/aedev_project_tpls)](
    https://gitlab.com/aedev-group/aedev_project_tpls/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/aedev_project_tpls)](
    https://gitlab.com/aedev-group/aedev_project_tpls/)
[![PyPIFormat](https://img.shields.io/pypi/format/aedev_project_tpls)](
    https://pypi.org/project/aedev-project-tpls/)
[![PyPILicense](https://img.shields.io/pypi/l/aedev_project_tpls)](
    https://gitlab.com/aedev-group/aedev_project_tpls/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/aedev_project_tpls)](
    https://libraries.io/pypi/aedev-project-tpls)
[![PyPIDownloads](https://img.shields.io/pypi/dm/aedev_project_tpls)](
    https://pypi.org/project/aedev-project-tpls/#files)



## installation

execute the following command to install the
aedev.project_tpls package
in the currently active virtual environment:
 
```shell script
pip install aedev-project-tpls
```

if you want to contribute to this portion then first fork
[the aedev_project_tpls repository at GitLab](
https://gitlab.com/aedev-group/aedev_project_tpls "aedev.project_tpls code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(aedev_project_tpls):

```shell script
pip install -e .[dev]
```

the last command will install this package portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/aedev-group/aedev_project_tpls/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

the documentation of the source code of this portion is available at
[ReadTheDocs](
https://aedev.readthedocs.io/en/latest/_autosummary/aedev.project_tpls.html
"aedev_project_tpls documentation").


